package
Version:
v0.5.2
Opens a new window with list of versions in this module.
Published: Jul 8, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Enable enables prometheus.
Enabled returns if prometheus is enabled.
StartAgent starts a prometheus agent.
type Config struct {
Host string `config:",optional"`
Port int `config:",default=9101"`
Path string `config:",default=/metrics"`
}
A Config is a prometheus config.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.